==> haskell-quickcheck-instances-0.3.22-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-instances
version: 0.3.22
id: quickcheck-instances-0.3.22-6fDuoT73Lx93kICL53ruCA
key: quickcheck-instances-0.3.22-6fDuoT73Lx93kICL53ruCA
license: BSD-3-Clause
copyright: Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/qc-instances
synopsis: Common quickcheck instances
description:
    QuickCheck instances.
    .
    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.
    .
    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.
    .
    For information on writing a test-suite with Cabal
    see <https://www.haskell.org/cabal/users-guide/developing-packages.html#test-suites>
category: Testing
abi: a4e37ffb88de8a2d4a7e5c785a2c6ed3
exposed: True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup
    Test.QuickCheck.Instances.Tagged Test.QuickCheck.Instances.Text
    Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-instances-0.3.22
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-instances-0.3.22
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-instances-0.3.22
hs-libraries: HSquickcheck-instances-0.3.22-6fDuoT73Lx93kICL53ruCA
depends:
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA array-0.5.3.0
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    splitmix-0.0.3-H9sGLbdTiFIBMFODPQLh0t
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    time-compat-1.9.2.2-EKNycbtwZG1E2L9BrHYlhu transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.22-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-instances
version: 0.3.22
id: quickcheck-instances-0.3.22-KYU7WtEhMxd7UzhGsfMGck
key: quickcheck-instances-0.3.22-KYU7WtEhMxd7UzhGsfMGck
license: BSD-3-Clause
copyright: Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/qc-instances
synopsis: Common quickcheck instances
description:
    QuickCheck instances.
    .
    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.
    .
    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.
    .
    For information on writing a test-suite with Cabal
    see <https://www.haskell.org/cabal/users-guide/developing-packages.html#test-suites>
category: Testing
abi: 92644370aefc92e8614502b0fc2492a6
exposed: True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup
    Test.QuickCheck.Instances.Tagged Test.QuickCheck.Instances.Text
    Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-instances-0.3.22
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-instances-0.3.22
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-instances-0.3.22
hs-libraries: HSquickcheck-instances-0.3.22-KYU7WtEhMxd7UzhGsfMGck
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW array-0.5.3.0
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    splitmix-0.0.3-FghYurqzSDK8LuM9E0TBHw
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    time-compat-1.9.2.2-8WlSw3GNlSRBh3Oa2ct2i6 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
